@@ -1,5 +1,8 @@
+# Copyright (c) OpenMMLab. All rights reserved.
 from .anchor import *  # noqa: F401, F403
+from .bbox import *  # noqa: F401, F403
 from .evaluation import *  # noqa: F401, F403
+from .hook import *  # noqa: F401, F403
 from .motion import *  # noqa: F401, F403
 from .optimizer import *  # noqa: F401, F403
 from .track import *  # noqa: F401, F403
