@@ -1,8 +1,9 @@
+# Copyright (c) OpenMMLab. All rights reserved.
 from .aggregators import *  # noqa: F401,F403
 from .backbones import *  # noqa: F401,F403
 from .builder import (AGGREGATORS, MODELS, MOTION, REID, TRACKERS,
-                      build_aggregator, build_detector, build_model,
-                      build_motion, build_reid, build_tracker)
+                      build_aggregator, build_model, build_motion, build_reid,
+                      build_tracker)
 from .losses import *  # noqa: F401,F403
 from .mot import *  # noqa: F401,F403
 from .motion import *  # noqa: F401,F403
@@ -10,10 +11,11 @@ from .reid import *  # noqa: F401,F403
 from .roi_heads import *  # noqa: F401,F403
 from .sot import *  # noqa: F401,F403
 from .track_heads import *  # noqa: F401,F403
+from .trackers import *  # noqa: F401,F403
 from .vid import *  # noqa: F401,F403
+from .vis import *  # noqa: F401,F403
 
 __all__ = [
     'AGGREGATORS', 'MODELS', 'TRACKERS', 'MOTION', 'REID', 'build_model',
-    'build_tracker', 'build_motion', 'build_aggregator', 'build_reid',
-    'build_detector'
+    'build_tracker', 'build_motion', 'build_aggregator', 'build_reid'
 ]
