@@ -2,6 +2,9 @@
 from .base import BaseMultiObjectTracker
 from .byte_track import ByteTrack
 from .deep_sort import DeepSORT
+from .qdtrack import QDTrack
 from .tracktor import Tracktor
 
-__all__ = ['BaseMultiObjectTracker', 'Tracktor', 'DeepSORT', 'ByteTrack']
+__all__ = [
+    'BaseMultiObjectTracker', 'Tracktor', 'DeepSORT', 'ByteTrack', 'QDTrack'
+]
