@@ -1,4 +1,6 @@
 # Copyright (c) OpenMMLab. All rights reserved.
+from .quasi_dense_embed_head import QuasiDenseEmbedHead
+from .quasi_dense_track_head import QuasiDenseTrackHead
 from .roi_embed_head import RoIEmbedHead
 from .roi_track_head import RoITrackHead
 from .siamese_rpn_head import CorrelationHead, SiameseRPNHead
@@ -6,5 +8,6 @@ from .stark_head import CornerPredictorHead, StarkHead
 
 __all__ = [
     'CorrelationHead', 'SiameseRPNHead', 'RoIEmbedHead', 'RoITrackHead',
-    'StarkHead', 'CornerPredictorHead'
+    'StarkHead', 'CornerPredictorHead', 'QuasiDenseEmbedHead',
+    'QuasiDenseTrackHead'
 ]
