@@ -2,10 +2,11 @@
 from .base_tracker import BaseTracker
 from .byte_tracker import ByteTracker
 from .masktrack_rcnn_tracker import MaskTrackRCNNTracker
+from .quasi_dense_embed_tracker import QuasiDenseEmbedTracker
 from .sort_tracker import SortTracker
 from .tracktor_tracker import TracktorTracker
 
 __all__ = [
     'BaseTracker', 'TracktorTracker', 'SortTracker', 'MaskTrackRCNNTracker',
-    'ByteTracker'
+    'ByteTracker', 'QuasiDenseEmbedTracker'
 ]
